from setuptools import find_packages, setup

setup(
    name='gc-itva-core',
    version='0.0.1',
    description='Python REST API client for Guacamole 0.9.13 version',
    author='author',
    author_email='xxxxxxxx@163.com',
    url='https://github.com/xxxxx',
    # packages=find_packages(),
    packages=['gc-itva-core'],
    install_requires=['requests']
)
